==> dice-0.1.1-134-x86_64.pkg.tar.zst: usr/share/haskell/register/dice.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 dice
version:              0.1.1
visibility:           public
id:                   dice-0.1.1-ACuiVXnbdJb3XWmXQBIsF0
key:                  dice-0.1.1-ACuiVXnbdJb3XWmXQBIsF0
license:              Unlicense
maintainer:           Naïm Favier <n@monade.li>
author:               James Cook <mokus@deepbondi.net>
stability:            work-in-progress
synopsis:             Simplistic D&D style dice-rolling system.
description:
    Simplistic D&D style dice-rolling system.

    > $ dice "2d10 + 2 * (d100 / d6)"
    > (5+2) + 2 * 64 / 2 => 71

category:             Game
abi:                  801ccc99ab84523a662063d12833f1da
exposed:              True
exposed-modules:      Data.Random.Dice
import-dirs:          /usr/lib/ghc-9.4.8/site-local/dice-0.1.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/dice-0.1.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/dice-0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/dice
hs-libraries:         HSdice-0.1.1-ACuiVXnbdJb3XWmXQBIsF0
depends:
    base-4.17.2.1 mtl-2.2.2 parsec-3.1.16.1
    random-1.2.1.3-9Bk1Rk8uHFTJVqAMIpxjnc
    random-fu-0.3.0.1-9v6y5i9RtgI3ekiL4dJfsS

haddock-interfaces:   /usr/share/doc/dice/html/dice.haddock
haddock-html:         /usr/share/doc/dice/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> dice-0.1.1-136-x86_64.pkg.tar.zst: usr/share/haskell/register/dice.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 dice
version:              0.1.1
visibility:           public
id:                   dice-0.1.1-Bx7gNebfAKLHnDJ8ZIlU1b
key:                  dice-0.1.1-Bx7gNebfAKLHnDJ8ZIlU1b
license:              Unlicense
maintainer:           Naïm Favier <n@monade.li>
author:               James Cook <mokus@deepbondi.net>
stability:            work-in-progress
synopsis:             Simplistic D&D style dice-rolling system.
description:
    Simplistic D&D style dice-rolling system.

    > $ dice "2d10 + 2 * (d100 / d6)"
    > (5+2) + 2 * 64 / 2 => 71

category:             Game
abi:                  15ebe43433fbf1f4688780bef92c2985
exposed:              True
exposed-modules:      Data.Random.Dice
import-dirs:          /usr/lib/ghc-9.4.8/site-local/dice-0.1.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/dice-0.1.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/dice-0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/dice
hs-libraries:         HSdice-0.1.1-Bx7gNebfAKLHnDJ8ZIlU1b
depends:
    base-4.17.2.1 mtl-2.2.2 parsec-3.1.16.1
    random-1.2.1.3-8ADb21VvJl3AtsgmJLZ0Jg
    random-fu-0.3.0.1-H0dOptIdP7ULAwvjzDqwBD

haddock-interfaces:   /usr/share/doc/dice/html/dice.haddock
haddock-html:         /usr/share/doc/dice/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
